/**

	Level collection chooser.

	Copyright (C) 2010, 2011 Glad Deschrijver <glad.deschrijver@gmail.com>

	This file is part of qmlsokoban.

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, see <http://www.gnu.org/licenses/>.

*/

import QtQuick 1.0

Rectangle {
	id: levelCollectionArea
	width: levelCollectionListView.contentWidth // see next alias below

	property alias contentWidth: levelCollectionListView.contentWidth // let levelCollectionListView.contentWidth be fixed and let levelCollectionArea.width depend on levelCollectionListView.contentWidth and be variable, and not conversely, so that making levelCollectionArea smaller during hiding doesn't change the text width, this is necessary for not screwing up the text wrap
	property variant items: [qsTr("Simple Sokoban"), qsTr("Original levels"), qsTr("Extra levels"), qsTr("Still more"), qsTr("For the kids"), qsTr("Dimitri and Yorick"), qsTr("MacTommy Inventions"), qsTr("Yoshios Autogenerated")]

	signal levelCollectionChosen(string name)

	border { color: "#444444"; width: 2 }
	radius: 5
	gradient: Gradient {
		GradientStop { position: 0; color: "#666666" }
		GradientStop { position: 1; color: "#333333" }
	}

	ListView {
		id: levelCollectionListView
		anchors.fill: parent
		clip: true

		model: ListModel {
			ListElement { name: "levels_simple_sokoban" }
			ListElement { name: "levels_original" }
			ListElement { name: "levels_extra" }
			ListElement { name: "levels_still_more" }
			ListElement { name: "levels_for_the_kids" }
			ListElement { name: "levels_dimitri_and_yorick" }
			ListElement { name: "levels_mactommy_inventions" }
			ListElement { name: "levels_yoshios_autogenerated" }
		}

		delegate: Item {
			width: parent.width - 2 * anchors.topMargin
			height: listItemText.height + 8
			Rectangle {
				anchors.fill: parent
				color: "black"
				opacity: index % 2 ? 0.1 : 0.2
			}

			Text {
				id: listItemText
				anchors {
					left: parent.left
					right: parent.right
					margins: 4
					verticalCenter: parent.verticalCenter
				}
				color: "white"
				wrapMode: Text.Wrap
				text: items[index]
			}

			MouseArea {
				anchors.fill: parent
				onClicked: {
					levelCollectionChosen(name);
					levelCollectionArea.state = "hidden";
				}
			}
		}
	}

	states: State {
		name: "hidden"
		PropertyChanges {
			target: levelCollectionArea
			opacity: 0
			width: 0
			anchors.leftMargin: 0 // set this to 0 so that the margins of the smaller version of the menu are decent
		}
	}

	transitions: Transition {
		NumberAnimation {
			properties: "opacity, width, anchors.leftMargin"
			duration: 400
		}
	}
}
